package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@("`0`````````````#`!8````!````````+!``````````0```````
M`+1(``````!``#@`"0!``!L`&@````8````%`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*PH````````K"@`
M```````0``````$````&````````K=````````"]T````````+W0````````
M!4@````````5>````````!```````@````8```````"MX````````+W@````
M````O>`````````"(`````````(@``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````IB@```````"F*````````*8H`````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*W0````````O=``````
M``"]T`````````(P`````````C```````````2]L:6(O;&0V-"YS;RXQ````
M```$````$`````%'3E4```````````,````"``````````0````4`````T=.
M50#W0Y*B;8V7J.%?&X("XPXFM@W#)```````````````80````````!D````
M`````````````````````````````````````$$`````````````````````
M`````````#P``````````````````````````````$4`````````'@``````
M`````````````"4`````````'P````````!9````````````````````%@``
M``````!-`````````$X`````````-P````````!;`````````&(`````````
M,``````````^```````````````````````````````@`````````%4`````
M````1@``````````````````````````````40````````!7`````````%0`
M`````````````````````````````&,`````````4```````````````````
M`#8````````````````````Y````````````````````)@````````!<````
M`````$P`````````1P````````````````````,`````````7P``````````
M`````````"<`````````&P``````````````````````````````5@``````
M```D`````````#(`````````*```````````````````````````````#0``
M`````````````````!H`````````````````````````````````````````
M```````````*`````````$@`````````1`````````!``````````%H`````
M````0P``````````````````````````````70````````!3`````````"X`
M````````!P````````!/``````````D`````````.```````````````````
M`#$`````````````````````````````````````````7@````````!2````
M````````````````+P````````!8`````````"H`````````20`````````]
M`````````"P`````````````````````````````````````````````````
M```````````````````````````````````&````````````````````````
M````````````````````````````````````````````````````````````
M``````````!@`````````````````````````````````````````!$`````
M`````````````````````````````````````````````````````````!<`
M```````````````````8````````````````````````````````````````
M````````````%```````````````````````````````$@``````````````
M``````0````````````````````A`````````&$`````````````````````
M``````````````````````````````!*````````````````````````````
M```M`````````!4`````````#```````````````````````````````&0``
M```````.`````````#0````````````````````C````````````````````
M*P`````````S`````````!T`````````"P`````````"````````````````
M``````````````!"````````````````````.P`````````_`````````#H`
M````````(@``````````````````````````````````````````````````
M```````````````````````/`````````!``````````-0``````````````
M``````4`````````'``````````I````````````````````$P``````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````(`````````$L`````````````
M`!$```!*````!`````B$!$`%`!`0((``AH````(H"00@"0``*8((`@2Z11B@
MB`````````!*````3@```%(```!3````60```%H```!;````70```%X`````
M````8````&$```!B````8P``````````']_%;@[OT^HM1][.?)I_:[:;Q2X.
MY/\@#O&-N'S49-4<6''9`<9'XL#C2ZQ\DN.Z+#_EPF!LH?IOBP&SUD,):V;,
MKV?LU45"TW`'B9[B%`V>X\W:[=MB,PN7.@V;G*E_"@*GX4G[X*,`````````
M``````````````````````````````````,```P````````AP```````````
M```"B1(````````````````````````````#"R(`````````````````````
M```````!W1(`````````````````````````````#"``````````````````
M```````````#21$````````````````````````````#GA(`````````````
M```````````````"UA$````````````````````````````#*!(`````````
M```````````````````!#!(````````````````````````````">Q(`````
M```````````````````````"I!(`````````````````````````````KQ(`
M```````````````````````````!?A(````````````````````````````"
MD!(`````````````````````````````?Q(`````````````````````````
M```!!Q(````````````````````````````"1Q(`````````````````````
M```````"W1(`````````````````````````````_!$`````````````````
M```````````"91(````````````````````````````!8A(`````````````
M````````````````WA$````````````````````````````!,!(`````````
M````````````````````O1(````````````````````````````!K!(`````
M```````````````````````"Y!(````````````````````````````"'Q(`
M```````````````````````````!\Q(````````````````````````````!
MF1(````````````````````````````"=!(`````````````````````````
M```"6!(````````````````````````````!I1(`````````````````````
M```````!/A(````````````````````````````"[1(`````````````````
M````````````*"`````````````````````````````",1(`````````````
M```````````````!MQ$````````````````````````````"^A(`````````
M````````````````````7Q(````````````````````````````#-Q(`````
M```````````````````````!UA(`````````````````````````````CA(`
M```````````````````````````!XA(````````````````````````````#
M&A(`````````````````````````````FA(`````````````````````````
M```!5Q(````````````````````````````"7Q(`````````````````````
M```````!'1(````````````````````````````";1(`````````````````
M````````````41(````````````````````````````!$1(`````````````
M```````````````"JQ(````````````````````````````!CA(`````````
M```````````````````"EA(`````````````````````````````ZQ(`````
M```````````````````````#,!(````````````````````````````"@A(`
M```````````````````````````#2B$````````````````````````````!
M<!(`````````````````````````````;A(`````````````````````````
M````SQ(````````````````````````````!3A(`````````````````````
M```````#`1(````````````````````````````"-A(`````````````````
M````````````-R`````````````````````````````#2Q$`````````````
M```````````````"S!(````````````````````````````!^Q(`````````
M```````````````````"N1(````````````````````````````"/A(`````
M```````````````````````"#Q(````````````````````````````"Q!(`
M```````````````````````````#IQ(```X```````!D6`````````"@```#
M=1(```\```````!ED``````````````#S!(```X```````!5H`````````JX
M```#1!(```X````````I@`````````*.```#>Q(```X```````!-R```````
M```&```$.A(```X```````!-T`````````)(```$-!(```P````````AP```
M```````````$9Q(```X```````!@6`````````0````#6A```!@```````##
M&``````````````#LQ(```X```````!0&`````````!*```#YA$``!``````
M``!EP``````````$```#9A```!@```````#32``````````````$,A(```X`
M``````!,.``````````\```$1Q(```X```````!44`````````%.```$61(`
M``X```````!3<`````````"@```#V1```!<```````#"8``````````````#
MP!(```X```````!0:`````````$N```#4Q```!<```````##&```````````
M```$&Q$``!<```````##$``````````(```#:Q(```X```````!EB```````
M```"```$"Q(```X```````!E(`````````!H```#WQ(```X````````L$```
M```````````#VR```!<```````#"8``````````````#C!(```X```````!4
M$``````````Z```#]1(```X```````!,V`````````#J```$)1(```X`````
M``!1F`````````'4`&QI8G!E<FPN<V\`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S
M=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR
M7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO
M861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C
M`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!O<&5N-C0`<F5A9`!?
M7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C
M;&]S90!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP
M`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL
M;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<G-T<@!R;61I<@!?
M7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`
M;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE
M;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P
M<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`%]?;&EB8U]S=&%R=%]M86EN`%]?
M96YV:7)O;@!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I
M;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK
M=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N
M=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI
M=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR
M`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N-``O=7-R+VQI8B]P
M97)L-2\U+C(V+C$O<S,Y,'@M;&EN=7@M=&AR96%D+6UU;'1I+T-/4D4`````
M`````@`"``,````"``(``@`"``(``@`"```````"```````$``(````"````
M```````````"``4``P````(``@`"````!@````(````"`````@`#`````P`$
M```````"`````@``````!@````0````"``(``@````````````(``@````(`
M`@`#``(``@`#``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!`````0`!```!Q@```!`````@#6EI$@````,`
M``1]```````!``0```(5````$``````):1ET````!@``!(<````0"6D9<@``
M``4```23````$`UI:10````$```$GP```!`-:6D2`````@``!'T`````````
M````O=``````````#````````"T0````````O=@`````````#````````"S`
M````````PB@`````````#````````,)H````````PD``````````#```````
M`"F`````````PF@`````````#````````,)H````````PG``````````#```
M`````&<J````````PG@`````````#````````&<2````````PH``````````
M#````````&<:````````PH@`````````#````````&=`````````PI``````
M````#````````&<H````````PI@`````````#````````&<Z````````PJ@`
M````````#````````&@P````````PK``````````#````````&7$````````
MPL``````````#````````&;6````````PL@`````````#````````&;:````
M````PM``````````#````````&@V````````PM@`````````#````````&8F
M````````PN``````````#````````&@^````````PO``````````#```````
M`&A"````````PO@`````````#````````&A(````````PQ``````````#```
M`````&CJ````````P?`````#````"@``````````````````P?@````%````
M"@``````````````````P@`````(````"@``````````````````P@@````.
M````"@``````````````````PA`````4````"@``````````````````PA@`
M```7````"@``````````````````PB`````D````"@``````````````````
MPC`````F````"@``````````````````PC@````Q````"@``````````````
M````PD@````]````"@``````````````````PE````!"````"@``````````
M````````PE@```!#````"@``````````````````P!@````"````"P``````
M````````````P"`````#````"P``````````````````P"@````$````"P``
M````````````````P#`````'````"P``````````````````P#@````)````
M"P``````````````````P$`````*````"P``````````````````P$@````+
M````"P``````````````````P%`````,````"P``````````````````P%@`
M```-````"P``````````````````P&`````/````"P``````````````````
MP&@````0````"P``````````````````P'`````1````"P``````````````
M````P'@````2````"P``````````````````P(`````3````"P``````````
M````````P(@````5````"P``````````````````P)`````6````"P``````
M````````````P)@````8````"P``````````````````P*`````9````"P``
M````````````````P*@````:````"P``````````````````P+`````;````
M"P``````````````````P+@````<````"P``````````````````P,`````=
M````"P``````````````````P,@````>````"P``````````````````P-``
M```?````"P``````````````````P-@````@````"P``````````````````
MP.`````A````"P``````````````````P.@````B````"P``````````````
M````P/`````C````"P``````````````````P/@````E````"P``````````
M````````P0`````G````"P``````````````````P0@````H````"P``````
M````````````P1`````I````"P``````````````````P1@````J````"P``
M````````````````P2`````K````"P``````````````````P2@````L````
M"P``````````````````P3`````M````"P``````````````````P3@````N
M````"P``````````````````P4`````O````"P``````````````````P4@`
M```P````"P``````````````````P5`````R````"P``````````````````
MP5@````S````"P``````````````````P6`````T````"P``````````````
M````P6@````U````"P``````````````````P7`````V````"P``````````
M````````P7@````W````"P``````````````````P8`````X````"P``````
M````````````P8@````Y````"P``````````````````P9`````Z````"P``
M````````````````P9@````\````"P``````````````````P:`````^````
M"P``````````````````P:@````_````"P``````````````````P;````!`
M````"P``````````````````P;@```!!````"P``````````````````P<``
M``!$````"P``````````````````P<@```!%````"P``````````````````
MP=````!&````"P``````````````````P=@```!'````"P``````````````
M````P>````!(````"P``````````````````P>@```!)````"P``````````
MZV_P,``DN00`'Z?[_V#C$/```"3`P```3Q;`$```4"/C$!````2Y`@`1IX0`
M`PWAXT#Q$``$ZV_PT``$!_0'!^,0\#@`),`0``!._=('\#`0".,0$!``!`?Q
M!P`'``<`P!```$[\XQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```3O#C
M$!````0'\0T0XQ`0#``4P/3____5````&,`0``!.Y.,0$```!`?Q#1#C$!`,
M`!3`]/___\4````PP!```$[8XQ`0```$!_$-$.,0$`P`%,#T____M0```$C`
M$```3LSC$!````0'\0T0XQ`0#``4P/3___^E````8,`0``!.P.,0$```!`?Q
M#1#C$!`,`!3`]/___Y4```!XP!```$ZTXQ`0```$!_$-$.,0$`P`%,#T____
MA0```)#`$```3JCC$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!.G.,0
M$```!`?Q#1#C$!`,`!3`]/___V4```#`P!```$Z0XQ`0```$!_$-$.,0$`P`
M%,#T____50```-C`$```3H3C$!````0'\0T0XQ`0#``4P/3___]%````\,`0
M``!.>.,0$```!`?Q#1#C$!`,`!3`]/___S4```$(P!```$YLXQ`0```$!_$-
M$.,0$`P`%,#T____)0```2#`$```3F#C$!````0'\0T0XQ`0#``4P/3___\5
M```!.,`0``!.5.,0$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```$Y(XQ`0
M```$!_$-$.,0$`P`%,#T___^]0```6C`$```3CSC$!````0'\0T0XQ`0#``4
MP/3___[E```!@,`0``!.,.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!``
M`$XDXQ`0```$!_$-$.,0$`P`%,#T___^Q0```;#`$```3ACC$!````0'\0T0
MXQ`0#``4P/3___ZU```!R,`0``!.#.,0$```!`?Q#1#C$!`,`!3`]/___J4`
M``'@P!```$X`XQ`0```$!_$-$.,0$`P`%,#T___^E0```?C`$```3?3C$!``
M``0'\0T0XQ`0#``4P/3___Z%```"$,`0``!-Z.,0$```!`?Q#1#C$!`,`!3`
M]/___G4```(HP!```$W<XQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```
M3=#C$!````0'\0T0XQ`0#``4P/3___Y5```"6,`0``!-Q.,0$```!`?Q#1#C
M$!`,`!3`]/___D4```)PP!```$VXXQ`0```$!_$-$.,0$`P`%,#T___^-0``
M`HC`$```3:SC$!````0'\0T0XQ`0#``4P/3___XE```"H,`0``!-H.,0$```
M!`?Q#1#C$!`,`!3`]/___A4```*XP!```$V4XQ`0```$!_$-$.,0$`P`%,#T
M___^!0```M#`$```38CC$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!-
M?.,0$```!`?Q#1#C$!`,`!3`]/___>4```,`P!```$UPXQ`0```$!_$-$.,0
M$`P`%,#T___]U0```QC`$```363C$!````0'\0T0XQ`0#``4P/3___W%```#
M,,`0``!-6.,0$```!`?Q#1#C$!`,`!3`]/___;4```-(P!```$U,XQ`0```$
M!_$-$.,0$`P`%,#T___]I0```V#`$```34#C$!````0'\0T0XQ`0#``4P/3_
M__V5```#>,`0``!--.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```$TH
MXQ`0```$!_$-$.,0$`P`%,#T___]=0```ZC`$```31SC$!````0'\0T0XQ`0
M#``4P/3___UE```#P,`0``!-$.,0$```!`?Q#1#C$!`,`!3`]/___54```/8
MP!```$T$XQ`0```$!_$-$.,0$`P`%,#T___]10```_#`$```3/CC$!````0'
M\0T0XQ`0#``4P/3___TU```$",`0``!,[.,0$```!`?Q#1#C$!`,`!3`]/__
M_24```0@P!```$S@XQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```3-3C
M$!````0'\0T0XQ`0#``4P/3___T%```$4,`0``!,R.,0$```!`?Q#1#C$!`,
M`!3`]/___/4```1HP!```$R\XQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`
M$```3+#C$!````0'\0T0XQ`0#``4P/3___S5```$F,`0``!,I.,0$```!`?Q
M#1#C$!`,`!3`]/___,4```2PP!```$R8XQ`0```$!_$-$.,0$`P`%,#T___\
MM0``!,C`$```3(SC$!````0'\0T0XQ`0#``4P/3___RE```$X,`0``!,@.,0
M$```!`?Q#1#C$!`,`!3`]/___)4```3XP!```$QTXQ`0```$!_$-$.,0$`P`
M%,#T___\A0``!1#`$```3&CC$!````0'\0T0XQ`0#``4P/3___QU```%*,`0
M``!,7.,0$```!`?Q#1#C$!`,`!3`]/___&4```5`P!```$Q0XQ`0```$!_$-
M$.,0$`P`%,#T___\50``!5C`$```3$3C$!````0'\0T0XQ`0#``4P/3___Q%
M```%<.MO\#``),#0```^1>/P_SC_<>,P\*@`).-`\*``)%`@\+2R3P`0ZQ$`
M(``-LD\`$4%`\*!!,/"HT@?PP!`H02#PM,#E___^#\1(``!,.,0H``!,/;D$
M`#3`Y0``'9#$&```3!V5`!``IX0`P\2X``!,$N,@L```%L#E____=)8")/KC
M(+```!;`Y?___VQ8$/"TE@$D^NPA``4`V.,0T```!+D4`"+L(0#3(&7K(@`#
M``W`Y?___5?`$```5'SE3!````3`$```'T_C,/"H``3C0#````3C$"`(`"3C
M0"```"3$&```3%?C$"`0`"3$*P``5%W`$```'SGC$"`8`"180/"T[$P`(0%^
M[%3__@#8[%4=O`-501`P"$$%,!"G6``%N10`->.P$```!.LS``,`#>.S+_C_
M)*=:``&G&P`([!#_\6!D[!0`!`#8N10`$>L1``,`#>,1+_C_<;D$`%*G2@`#
MIVD``+D4`$3E2!````#`,```$,/$*```5"3`Y?___D$8LNPH`%H`?L0H``!4
M&D&@\+S`Y?___'6Y!``ZP"```!VIP.4```R=["@`.@!\Q"@``%0'P.7___PD
MP.7___WQLD\`$.L1`"``#;)/`!&Y%``KU0?PP!`HIW0`4>-`\3@`!.MO\/@`
M!`?TP.7___QYQ"L``%/F["@`10!\P.7___OPQ+@``$M%XR"P```6P.7___ZG
MD@`I(:?T_RO`$```4\SC(!````*GA``9P.4``!Q4I_3_OL0H``!3P\#E___^
M4!BRI_3_HL0X``!+,L`@```>'<#E___]9+D$`#K`(```'2#`Y0``##S$*P``
M4Z7L*/^?`'RG]/_;P.7___O1IRD``<#E___\S`<'04#P".,P\```!*<)__"Y
M@`#PI_O_4-<'\`#P`.OO\*``)$%P\*#`8```'*G`4```''+`(```2O_C("``
M``3`Y?___-D```<'P!```$M@P"```$M=["$`"H!DQ!@``$K'[!@`!`!\!_$'
M_@<'!P<'!\`0``!+3,`@``!+2;D)`!+K$0`#``KK,0`_``RY"``QZS,``0`*
M[#@`"@!\Q!@``$K2[!@`!`!\!_$'_@<'!P?KO_!8`"3`L```2RGC\/]@_W&5
M`+``IW0`%<`0``!*B^,0$````J>$``C$*```2K_`Y?__^JC`Y?___[&2`;``
MXT#Q$``$Z[_P^``$!_0'!\#T____N`<'LD\`$.L1`"``#;)/`!'K;_`P`"2G
M60`(X_#\V/]QT@?S(!`H0;`@.$$0\*"Y!`!!XS"P```$ZP,`(``,XP!````D
MP#H`````XS!`"``D0;"P"*=+`!"G5__MITD`0.,P$&@`!.,P$$``@N,P$!``
M@N,P$```@NQ3(+\A5>Q3(#X!5N-0$(``)*<;``BG1__IX[`@"``$XY`@$``$
MXP`@&``$XQ#PH``$N><`2<(:6H)YF;F``$OC$"`@``BY@@!`XU`@```$[(4@
MOR55[(4@.@56N0@`@>L;``(`#+D(`(3L&P`A'E;C0/"H``3L<2"_`%7"2EJ"
M>9FYYW`YN8``-;F"`#G`B@````"YZ`!DZ]@`&P`,N0@`8^S8(#H%5NM%``(`
M#+D(`&WL10`A'E;`:@````"Y@@`4ZS8`&P`,N8``&.PV(#H%5KF"`!>SP0`C
MXZ#PN``$PJI:@GF9N0@`I[/-`'+C,/"P``3".EJ">9FY"``YN0@`,>L8``(`
M#.P8`"$>5KGG$(3`2@````"Y@`"&N8(`A+D(`#>YZ*!XXX#PP``$PHI:@GF9
MN>A`2.R!(+\`5<`Z`````+/!`"3CH/#(``3K1@`"``S"JEJ">9GL1@`A'E:Y
M"`"HN8(`%+F``!.Y@@`8L\T`@NO3`!L`#.S3(#H%5KD(`!BY"`!]ZX,``@`,
MP'H`````[(,`(1Y6N00`.+GG@(3`2@````"Y@`"'N8(`A+GHH&CC@/#0``3"
MBEJ">9FYZ$!([(,@OP!5L\$`).O7`!L`#.M'``(`#.S7(#H%5NQ'`"$>5KD(
M`!VY@@`TP!H`````XZ#PV``$N8``,<*J6H)YF;F"`#BY"`"HL\T`@NO1`!L`
M#.S1(#H%5KD(`#BY"`!MZX$``@`,P&H`````[($`(1Y6N00`&+GG@(3`2@``
M``"Y@`"&N8(`A+GHH'CC@/#@``3"BEJ">9FYZ$!([($@OP!5L\$`).O6`!L`
M#.M&``(`#.S6(#H%5NQ&`"$>5KD(`#VY@@`4P#H`````XZ#PZ``$N8``$\*J
M6H)YF;F"`!BY"`"HL\T`@NO3`!L`#.S3(#H%5KD(`!BY"`!]ZX,``@`,P'H`
M````[(,`(1Y6N00`.+GG@(3`2@````"Y@`"'N8(`A+GHH&CC@/#P``3"BEJ"
M>9FYZ$!([(,@OP!5L\$`).O7`!L`#.M'``(`#.S7(#H%5NQ'`"$>5KD(`!VY
M@@`TP!H`````XZ#P^``$N8``,<*J6H)YF;F"`#BY"`"HL\T`@NO1`!L`#.S1
M(#H%5KD(`#BY"`!MZX$``@`,P&H`````[($`(1Y6N>>`=,!*`````+F``':Y
M@@!TN00`&+GHH(?C</$```3">EJ">9FYZ$!'['$@OP!5L\$`).O6`!L`#.M&
M``(`#.S6(#H%5NQ&`"$>5KD(`#VY@@`4P#H`````XZ#Q"``$N8``$\*J6H)Y
MF;F"`!>Y"`"GL\T`<NO3`!L`#.S3(#H%5KD(`!>Y"`"-ZW,``@`,P(H`````
M[',`(1Y6N00`-[GG<'3`2@````"Y@`!XN8(`=+GHH&?C</$0``3">EJ">9FY
MZ$!'[',@OP!5L\$`).M(``(`#.Q(`"$>5KF"`#3KV``;``SLV"`Z!5:Y"``=
MP!H`````N>00@[/-`#*Y@@"'Z]$`&P`,N0@`@^S1(#H%5NLQ``(`#+D(`&WL
M,0`A'E;`:@````"Y!``3XZ#Q&``$N><P-,*J6H)YF;F``#:Y"`"G['0@OP!5
MN8(`-[GHH$/C,/$@``3".EJ">9FY"``W['$@OP!5L\$`(^O6`!L`#.LV``(`
M#.S6(#H%5NPV`"$>5KD(`(VY@@`3P(H`````XZ#Q*``$N8``&,*J6H)YF;F"
M`!>Y"`"GL\T`<NO8`!L`#.S8(#H%5KD(`!>Y"`!-ZW@``@`,P$H`````['@`
M(1Y6N>=P8\`Z`````+F``&2Y@@!CN>B@ANQG(+\`5>.@\3``!,*J6H)YF;D(
M`*/K-``"``SL-``A'E:Y@@!SZ]0`&P`,[-0@.@56N0@`'<`:`````+GD$$?C
M</$X``3">EJ">9FY"`!VZ]$`&P`,L\$`)^S1(#H%5NMQ``(`#.QQ`"$>5K/-
M`!*Y"`"-N8(`1L"*`````.QC(+\`5>O8`!L`#+F"`#?LV"`Z!5:Y@``XN8(`
M-KD(`$JYZ!`3N0@`3>LX``(`#.S4(+\`5>PX`"$>5NNM`!L`#.RM(#H%5KD$
M`(.Y"``:XS#Q0``$N>>`I\(Z;MGKH;F"`$JY"`!CN1H`9.PQ(+\`5>NM``(`
M#.M#`!L`#.RM`"$>5NQ#(#H%5KD$`-JY"`!&N>>@J.-@\4@`!+F"`*'":F[9
MZZ&Y!``6[&0@OP!5N1H`%[D:`!KKI@`;``SLIB`Z!5;K<P`"``RY"``:[',`
M(1Y6N>=PK;F"`*3C,/%0``3L02"_`%7".F[9ZZ&Y&@`XN1H`.NND`!L`#.RD
M(#H%5NN&``(`#+D(`#KLA@`A'E;C8/%8``2YYX"GPFINV>NAN8(`&KD:`&VY
M&@!A[-,@OP!5ZZ0``@`,ZQT`&P`,[*0`(1Y6[!T@.@56N0@`%NQA(+\`5;D$
M`$KCH/%@``3"JF[9ZZ&Y&@"GN>=`>+F"`'/K/0`"``RY&@"G[#T`(1Y6XW#Q
M:``$N><PU,)Z;MGKH;D:`'BY!`"'N><0?>L6`!L`#.P6(#H%5KD(`!KLT2"_
M`%7KK0`;``SLK2`Z!5:Y&@"'ZW8``@`,N0@`BNQV`"$>5KGG<&.Y@@!AXQ#Q
M<``$PAINV>NAN1H`%.Q((+\`5>ND`!L`#.RD(#H%5KD:`!;K;0`"``RY"``:
M[&T`(1Y6X]#Q>``$N>=@I\+:;MGKH;D:`-.Y@@"*N00`/>S1(+\`5>NM`!L`
M#.RM(#H%5KD:`#CKA``"``SLA``A'E:YZ*!#N>>`IKF"`*'C,/&```3L%""_
M`%7".F[9ZZ&Y&@`WN1H`.NNA`!L`#.RA(#H%5NM]``(`#+D(`#KL?0`A'E;C
MT/&(``2YYW"HPMINV>NAN8(`I+D$`$WLTR"_`%6Y&@!&N1H`2NNM`!L`#.RM
M(#H%5NMA``(`#.QA`"$>5KGHH!2YYV"GN8(`H^-`\9``!.PQ(+\`5<)*;MGK
MH;D:`$BY&@!*ZZ,`&P`,[*,@.@56ZXT``@`,N0@`2NR-`"$>5N/0\9@`!+GG
M@*;"VF[9ZZ&Y@@"AN00`'>S4(+\`5;D:`!>Y&@`:ZZT`&P`,[*T@.@56ZW,`
M`@`,[',`(1Y6N>B@,;GG<*BY@@"DXQ#QH``$[$,@OP!5PAINV>NAN1H`%KD:
M`!KKI``;``SLI"`Z!5;K;0`"``RY"``:[&T`(1Y6X]#QJ``$N>=@I\+:;MGK
MH;F"`*.Y!``][-$@OP!5N1H`.+D:`#KKK0`;``SLK2`Z!5;KA``"``SLA``A
M'E:YZ*!#N>>`IKF"`*'C,/&P``3L%""_`%7".F[9ZZ&Y&@`WN1H`.NNA`!L`
M#.RA(#H%5KD(`#KCH/&X``3"JF[9ZZ&Y&@"FZWT``@`,N00`:NQ]`"$>5KGG
M<-BY@@#4[$,@OP!5ZZ0`&P`,[*0@.@56N1H`;>O1``(`#.S1`"$>5KGHH!:Y
MY]"GN8(`H^-@\<``!.PQ(+\`5<)J;MGKH;D:`&BY&@!JZZ,`&P`,[*,@.@56
MN0@`:N.@\<@`!,*J;MGKH;D:`*?KA``"``RY!`!Z[(0`(1Y6N>>`3;F"`$'L
M%B"_`%7KH0`;``SLH2`Z!5:Y&@!TZT,``@`,[$,`(1Y6N>B@-[GG0*BY@@!J
MXW#QT``$PGINV>NAN1H`?;D:`':Y!`!G[-,@OP!5ZZ$``@`,ZWT`&P`,[*$`
M(1Y6['T@.@56N0@`=KGGH&3`>@````"Y@@`VN00`&N-@\=@`!.NG`!L`#,)J
M;MGKH>RG(#H%5KD:`&BY!`"*N1H`8^.@\>``!+D(`&C"JH\;O-SL@2"_`%6Y
M&@"DZTT``@`,[$T`(1Y6[-0@OP!5N8$`%+GDT#BY@``7N8$`$[D(`!K`:@``
M``#CH/'H``3K-@`;``S"JH\;O-SL-B`Z!5:Y"`"HN0@`,>N'``(`#.R'`"$>
M5NQX(+\`5;F!`$BYY'`=N8``1KF!`$&Y"`!*P#H`````XZ#Q\``$ZQ,`&P`,
MPJJ/&[S<[!,@.@56N0@`K;D(`!3K1@`"``SL1@`A'E;L9""_`%6YYD#8N>1@
MA[F``-.Y@0#8N0@`VL`:`````..@\?@`!.N!`!L`#,*JCQN\W.R!(#H%5KD(
M`*>Y"`"-ZW,``@`,[',`(1Y6N>9PU+D$`#>Y@`#1P'H`````N>1P1KF!`-2Y
M"`#:P(H`````XZ#R```$ZT@`&P`,PJJ/&[S<[$@@.@56N0@`IKD(`$WK80`"
M``SL80`A'E:Y!``6N>9@8^S1(+\`5;F``&BYY-`WN8$`8[D(`&K`2@````#C
MH/((``3K-``;``S"JH\;O-SL-"`Z!5:Y"`"GN0@`-NMX``(`#.QX`"$>5NQG
M(+\`5;GF<(&YY&`=N8``A+F!`(&Y"`"*P#H`````XZ#R$``$ZQ,`&P`,PJJ/
M&[S<[!,@.@56N0@`K;D(`!CKA``"``SLA``A'E;LV""_`%6Y@0!XN>301KF`
M`'.Y@0!TN0@`>L`:`````..@\A@`!.M!`!L`#,*JCQN\W.Q!(#H%5KD(`*:Y
M"`!'ZV,``@`,[&,`(1Y6N>9@>.R&(+\`5;F``'&YY(`]N8$`<[D(`'K`2@``
M``#CH/(@``3K-``;``S"JH\;O-SL-"`Z!5:Y"`"MN0@`-^MQ``(`#.QQ`"$>
M5KGF<-;L9R"_`%6Y@`#4N>1@&+F!`-&Y"`#:P#H`````ZZ0``@`,ZQ,`&P`,
M[*0`(1Y6[!,@.@56N0@`';GFH-?`&@````#L>B"_`%6Y!`!*N8``T[GD<*:Y
M@0#:XZ#R*``$PJJ/&[S<N0@`J+D(`-KK@0`;``SCH/(P``3L@2`Z!5;"JH\;
MO-RY"`"-N0@`INMC``(`#.QC`"$>5KGF8-2Y!``VN8``T<!J`````+GD8$>Y
M@0#4N0@`VL"*`````..@\C@`!.M(`!L`#,*JCQN\W.Q((#H%5KD(`*>Y"`!-
MZW$``@`,['$`(1Y6N>9PT[D$`!>Y@`#8P'H`````N>1P-KF!`-.Y"`#:P$H`
M````XZ#R0``$ZS0`&P`,PJJ/&[S<[#0@.@56N0@`IKD(`#WK:``"``SL:``A
M'E:YYF#1N00`AKF``-3`:@````"YY&`7N8$`T;D(`-K`.@````#CH/)(``3K
M$P`;``S"JH\;O-SL$R`Z!5:Y"`"GN0@`'>MT``(`#.QT`"$>5NS7(+\`5;F!
M`(>YY-!&N8``@[F!`(2Y"`"*P!H`````XZ#R4``$ZT$`&P`,PJJ/&[S<[$$@
M.@56N0@`IKD(`$CK@P`"``SL@P`A'E;L:""_`%6Y@0!XN>1@/;F``'&Y@0!S
MN0@`>L!*`````..@\E@`!.LT`!L`#,*JCQN\W.PT(#H%5KD(`*VY"``WZW$`
M`@`,['$`(1Y6[-<@OP!5N>9P&+GDT(:Y@``4N8$`&+D(`!K`.@````#CH/)@
M``3K@P`;``S"JH\;O-SL@R`Z!5:Y"`"FN0@`@>L4``(`#.P4`"$>5NQA(+\`
M5;F!`'&YY&!-N8``<[F!`'2Y"`!ZP(H`````XZ#R:``$ZT@`&P`,PJJ/&[S<
M[$@@.@56N0@`K;D(`$?K<P`"``SL<P`A'E;LUR"_`%6YYG`QN>30%KF``#BY
M@0`QN0@`.L!*`````..@\G``!.L4`!L`#,*JCQN\W.P4(#H%5KD(`*:Y"``3
MZS@``@`,[#@`(1Y6[&,@OP!5N8$`<[GD8(VY@`!TN8$`>+D(`'K`&@````#K
M@0`;``SL@2`Z!5:Y"`"'ZW0``@`,['0`(1Y6XZ#R>``$N8$`-\*JCQN\W+D$
M`$>Y"`"M[-<@OP!5N>30=KF``#&Y@0`W['@@OP!5N0@`.NNG`!L`#.RG(#H%
M5KD(`#KKH0`"``SLH0`A'E:Y!``:XZ#R@``$N8(`0<*JRF+!UKF"`(2Y"`!J
M[$,@OP!5N1H`:.ND`!L`#.RD(#H%5KD$`(;K9P`"``SL9P`A'E:YZ*!XN>=@
MH;F"`*/C@/*(``3L-R"_`%7"BLIBP=:Y"`"-N1H`BNNC`!L`#.RC(#H%5NO4
M``(`#+D(`(KLU``A'E:YY]"FXT#RD``$N8(`>L)*RF+!UKD:`$'L&""_`%7K
MH0`;``SLH2`Z!5:Y&@!'ZW,``@`,N0@`2NQS`"$>5KGG<*WC,/*8``2Y@@"*
MPCK*8L'6N1H`-NQD(+\`5>NF`!L`#.RF(#H%5KD:`#CK@0`"``RY"``Z[($`
M(1Y6N>>`I[F"`$KC$/*@``3KI@`"``S"&LIBP=;LI@`A'E:Y&@`=N00`:KD:
M`!2YYZ"HN00`0;F"`*/LTR"_`%7K'0`;``SL'2`Z!5:Y"``4XT#RJ``$[#$@
MOP!5PDK*8L'6N1H`1[D:`$KKHP`;``SLHR`Z!5;K?0`"``RY"`!*['T`(1Y6
MX]#RL``$N>=PIL+:RF+!UKF"`*&Y!``=[-0@OP!5N1H`&+D:`!KKK0`;``SL
MK2`Z!5;K@P`"``SL@P`A'E:YZ*`QN>>`I[F"`*3C$/*X``3L0R"_`%7"&LIB
MP=:Y&@`6N1H`&NND`!L`#.RD(#H%5NMM``(`#+D(`!KL;0`A'E;CT/+```2Y
MYV"HPMK*8L'6N8(`H[D$`#WLT2"_`%6Y&@`WN1H`.NNM`!L`#.RM(#H%5NMT
M``(`#.QT`"$>5KGHH$.YYW"FN8(`H>,P\L@`!.P4(+\`5<(ZRF+!UKD:`#BY
M&@`ZZZ$`&P`,[*$@.@56ZXT``@`,N0@`.NR-`"$>5N/0\M``!+GG@*?"VLIB
MP=:Y@@"DN00`3>S3(+\`5;D:`$:Y&@!*ZZT`&P`,[*T@.@56ZV$``@`,[&$`
M(1Y6N>B@%+GG8*BY@@"CXT#RV``$[#$@OP!5PDK*8L'6N1H`1[D:`$KKHP`;
M``SLHR`Z!5:Y"`!*XZ#RX``$PJK*8L'6ZWT``@`,['T`(1Y6N>=PUKF"`-&Y
M!``:N1H`&.R$(+\`5>NH`!L`#.RH(#H%5KD:`!WKTP`"``SLTP`A'E:YZ*`Q
MN>?0I[F"`$KC$/+H``3CH/+P``3"&LIBP=;"JLIBP=:Y&@`6N1H`I^QC(+\`
M5;D:`!3K1@`;``SL1B`Z!5:Y"``4['$@OP!5ZT@``@`,[$@`(1Y6N>=`C;F"
M`(.Y&@"HZS8``@`,N00`BNPV`"$>5N-@\O@`!+GG,*3":LIBP=:Y&@!MN><0
MVNL7`!L`#+D:`&WL%R`Z!5:Y!`#6N00`8>L7``(`#+D(`(;L%P`A'E:YYQ"C
MN8(`J.QX(+\`5>.`\P``!.MG`!L`#,**RF+!UNQG(#H%5KD:`(2Y"`!MN1H`
MBNS6(+\`5>NM`!L`#.RM(#H%5NM'``(`#.Q'`"$>5KGHH'BYYT"AN8(`IN.`
M\P@`!.QG(+\`5<**RF+!UKD:`(.Y&@"*ZZ8`&P`,[*8@.@56ZST``@`,N0@`
MBNP]`"$>5N.@("``!+GG,-2Y&@"CN8(`?<"J`````..@("``)./0\Q``!.RH
M(+\`5<+:RF+!UKD:`-'K&@`;``RY&@#7[!H@.@56ZW8``@`,N0@`'>QV`"$>
M5L`:`````+GG<&.Y&@`'N>@0.\`*`````.,`(!@`),`Z`````.,P(`@`)+F"
M`(;K`0`;``SCL/,8``3L`2`Z!5;"NLIBP=;K&@`"``RY!``[[!H@(1Y6N1H`
M-+D(`)&Y&@`XP)H`````XY`@$``DN0@`,+D:`%/`6@````#C4"```"2R3P`0
MZQ$`(``-LD\`$=4'\R`0**=T``GC0/.8``3K;_-8``0'],#E___OI0<'!P?K
M;_`P`"3C\/]@_W'L*`!G`'S$&```/O/C<!````*GA`!>XQ`@``"4[!@`!@!^
M[!8`-#U^IY@``..@<````J>$`".Y!`""N00`8[D4`)FY!`"WN00`2;D$`#BY
M!``JP.7___'Q["8`"0!^01F@`)4]$`"GA``B0;"P"..@L````J=T_^FY!``J
MXT#Q$``$ZV_PT``$!_2Y!`"209"0`>,0D```E.P8``8`?NP6__@]?AN2I_3_
MP[D)`+=!J:`!Z[L``P`*N00`*E"P8`#C0/$0``3K;_#0``0']*>I``"G]/_3
M!P<'!P<'ZZ_P4``DLD\`$./P_U#_<>L1`"``#;)/`!&Y!`"BT@?PJ!`H0;#P
MI+D$`#NY!``JP.7___]T["@`+0!\Q"@``#YJXQ#PI``4ZQ$``P`-XQ`@```(
MXR`0"``$XR`0```D["C_Y`!\01`0".,@$`@`!.,@$```).PF__@`?+D$`#NY
M!``JP.7___]*[";_V0!\LD\`$.L1`"``#;)/`!'5!_"H$"BG=``)XT#Q(``$
MZZ_Q```$!_3`Y?__[M$'!P<'ZV_P,``DLD\`$./P_TC_<>L1`"``#;)/`!&Y
M!`"RT@?PL!`HN00`HY4],`"G=``$0:`P`:<(``"Y!``:IYD``+D$`"NR7@"1
MIQ3__D$P\*RY"0":P.7___\"["@`LP!\IP@``*<9``"Y!``RLEX`$Z<4__ZY
M"0`2[!D`B*!EX]#PK``4Q(@``#WFZ]T``P`-XQ"P``"4[!@!"0!^[!@!!CU^
MN00`&Z?T``7L*``+/7Y!$!`!XR`0``"4[";_^`!^N0D`&[D4`!&Y!`!]02D0
M`N-P@```",#E___O,>,@<```).PH`.T`?.,0L```D.-`@```!.,P\*P`%.LS
M``,`#>,S0```!$(0,`!!L+`!P!L```#_IW0`$J?T`!/C$+```)!"$#`!0;"P
M`4$P,`'`&P```/^GA``%[!;_\CU^DCTP`*<9``#C(:```)!"(3`!IQL``>PF
M__D`?*<H``"R3P`0ZQ$`(``-LD\`$=4'\+`0*+D4`"*G=`"GXU#Q*``$ZV_P
MZ``$!_5!H*`!02`@`>,0K___D.,0+___<NP8_]\`?$&@H`%!("`!XQ"O__^0
MXQ`O__]R[!;_Z0!\I_3_S\2(```]2.-@@```!.,08````J>$`&^Y!``6IR@`
M`*?T``,8)^QR``$`V$$0$`CC,!````*G=/_WIRH``[D4`"+K(@`#``W`$```
M18GC$!```!*G=``TP!```$6!Y4P0```!P.7__^Z+XR#PH``D["@`1P!\N00`
M-KD4`&?KU@`#``VY!`!-P.7__^TIXQ#PH``$XQ"````DIVL``>,0\*``!.MF
M``,`#4$6$`#E2!````!0</"LI_3_#;D$`#*Y!``FP.7__^VKXR#PH``DXR"`
M```D["@`%`!\N10`9^O6``,`#:?T_]JG&0``I_3_#J<I`!"G>```I_3_IZ<H
M__^G]/]/P.7__^UJ!P<'!P<'ZV_P,``DLD\`$./P_L#_<>L1`"``#;)/`!'2
M!_$X$"CL*``)`'RY!`"BE0`@`*=T`!6R3P`0ZQ$`(``-LD\`$=4'\3@0**=T
M`)?C0/&P``3K;_%P``0'],#E___P&+D$`)+L*/_H`'Q!</"HN00`*<#E___O
MG.PH`&P`?$&P(!/`$```#C:G"```N00`*[)=`!*G%/_^IX3_Z\`0```.*KD$
M`"NR70`2IQ3__J>$_^"Y!``:IRD``+)>`"&G%/_^N00`.Z<9``"R7@`3IQ3_
M_KD)`!NY"0`J&B&G*@`"N10`(KD$`&K`Y?__[<'CL/"@`"2Y!`""ITG__Z<Y
M``'`4```#?K`Y?__[E*Y!`!'N00`.*<I``'`Y?__[VGL*``-_WY8$/#`IRA`
M`,`;``#P`.P2`!N`=KD$`"C`Y?__[8>Y!``HP.7__^Q2I_3_D;D$`"G`Y?__
M[WNY!``JP.7__^R&I_3_:+D$`"C`Y?___TNG]/_HP.7__^RJ!P<'!P<'ZZ_P
M4``DX_#_8/]QN00`HL2X```[U.,@L```%L#E___O-KD$`#KL0@(``-FG*0`!
MP.7__^\\["@`#@!^IR@``.-`\1``!+D4`"+KK_#P``0'].,@L```%L#E___O
M&%@0(ABG*$``P!L``/``[!(`$X!VXR"P```6P.7__^\(6!`B&*4OH`#`&P``
M\`#L$O_88':Y!``JISD``L#E___N=Q`BXT#Q$``$IRK__^NO\/``!(@@`!^Y
M%``B!_0'!P<'ZW_P.``DLD\`$./P_UC^<;D$`)+K$0`@``WC(/"@`7&R3P`1
MN00`<T&P\*#2!R``$"BY!``[ITD/_\`@```-/\#E___LE.PL`%8`?NP2__\`
MV,0X```[4[D4`*%8@#``03KPH)4`,`"GA``TN10`HKD$`$JY!``KISD`+\#E
M___MMNPH`"H`?+D6`"C`Y?__[IZY!`!:N00`2[D$`#G`Y?__[D6R3P`0XR#P
MH`%QZQ$`(``-LD\`$=4'(``0**=T`"WC0/$8`03K?_#@`00'].P6_]``?KD6
M`"C`Y?__[G>Y!`!'N00`.<#E___L$*?T_]O$&```.P-8@!``N18`*,#E___N
M9+D$`$>Y!``YP.7__^O]I_3_R,#E___KN`<'Z^_P<``DQ!@``#KIX_#_8/]Q
MXR`0```6P.7__^Y(P%```"SAQ$@``#K6P#````R_Z^_Q$``$P/3__^TI!P<'
M!^MO\#``)./P_UC_<<2X```ZQN,@L```%L!@```.*,#E___N)<#E____SN,@
ML```%L#E___N'+D$`%;E2/"@``#`0```"=#`,```#)_`Y?__[7[C0/$8``3K
M;_#8``0'].MO\#``)+)/`!#C\/](_7'K$0`@``WC(/"P`G&R3P`1T@<@`!`H
MP.7__^P!P!````R-XQ#PH``D0;#PKKD$`&*G21`!ISD``;D$`"O`4```#'?C
MH/"O`7'`Y?__[*BY!``KN00`.J=)$`#`Y?__ZY_L)``V`'ZY!`"RIRH``;D4
M`"+`Y?__Z_.Y!`"2["@`$`!\N10`N[D$`#JY!`!+P.7__^K%01N0`)(`$`"R
M3P`0XS#PL`)QZQ$`(``-LD\`$;D$`"G5!S``$"BG=``-XT#Q*`($ZV_PZ`($
M!_2GF0``I_3_YL#E___J\@<'!P<'!\#T____B`<'ZV_P,``DLD\`$./P_T#^
M<>L1`"``#>-`\+@!<;)/`!'2!T``$"BY!`"RN00`D\`@```,$D$P\+3`Y?__
M^RRG.0`ON00`HKD$`"O`Y?__Z]/L*``C`'RY!``[P"````P!P.7___OLN00`
M*[)/`!#C,/"X`7'K$0`@``VR3P`1U0<P`!`HIW0`W^-`\3`!!.MO\/`!!`?T
MIP@``+D$`!NY!``IP#````ODIYD``+)>`)&G%/_^&YO`Y?__[+WL*/_-`'RG
MF@`!P-````N708#PN)4`(`"GA`"([*@`#P!\IP@``+D$`!*Y!``ZLET`$Z<4
M__ZGA`!JN00`$J<(``"G.0``LEX`,:<4__ZY"0`R&!.Y%``SXS,O__]QE2\P
M`*=T`!&G&O__N10`,4%#(`"2`$``XS,O__]QE2\P`*>$__,:&:<X#__L$_^(
M(';CL/"H`"3`$```"XWC$/"@`"2G21``ISD``;D$`&+`4```#`ZY!``HP.7_
M_^N>Q'@``#ECXR!P```6P.7__^S%N00`..Q"`@``V:<I``'`Y?__[*OL)@`3
M`'[C('```!;`Y?__[+)8$"(8I2^``,`;``#P`.P2`"B`=L`P```+4J<I``#`
MY?__[##L*/]``'R5`"``IW3_?.RH``\`?*<(``"Y!``=N00`*K)=`!*G%/_^
MIX3_Y,`@```*^:<8``&G]/^:N00`**<Y``'`Y?__Z_SL)O_4`'ZY!``XP"``
M``L:P.7___L%N00`*,#E___I;*?T_Q;`Y?__Z<>Y!``2XR`@``"0["@`'0!\
ML\$`#QA"X_#_6/]QN00`(4)`\*>5+_"G01`0`>,P$```D+GB@"$80^PV__0`
M?+/-`/`'_KD$`"$'_@<'!P<'!^PH`"T`?.,P(```E.PX`"<`?J<(``"G&0``
MN00`0K)>`!2G%/_^XQ`?__]Q["$`,:!EE2\0`*=T`!RYZ2!!XQ`?__]QIT<`
M$>PX``DO?L`@```*P\#T___I$L`@```*@<#T___I#)4O$`"GA/_JN>D@0>-0
M'___<>PE`%<@9>PH`%3_?.,0'___<:='`#OL(?_=@&2YZ2`QXT`?__]Q["0`
M0"!E["@`/?]\XQ`?__]QIS<`+KD)`!*G21``[#$``@#9[#0`*R!EZ^_P<``D
MN00`,N/P_V#_<4%`$`&G61``P"```#CLP.7__^L)P"```#CFXT#Q$``$Z^_Q
M$``$!_25+Q``IW3_P*?T_\:5+Q``IX3_S:?T_]"G*0``!_ZG.0`!I_3_Q*=)
M``&G]/^M!P?KO_!8`"2R3P`0ZQ$`(``-LD\`$>/P_S#_<<`@```*1M('\,@0
M*,`0```J%=(A\*80`,#E___YO\`@```*/$&P\*#`Y?__^;?`(```"CC`Y?__
M^;'`(```"C?`Y?__^:O`(```"C7`Y?__^:7`(```"C?`Y?__^9_`(```"@G`
MY?__^9G`(```"C'`Y?__^9/`(```"C#`Y?__^8W`(```"B_`Y?__^8?`(```
M"?;`Y?__^8'`(```"BC`Y?__^7O`(```"B?`Y?__^76Y!``[P"````HEP.7_
M__CY["@`"P!\N00`,L`@```*!<#E___YPKD$`#O`(```"AO`Y?__^.;L*``+
M`'RY!``RP"````H9P.7___FON00`.\`@```*%\#E___XT^PH`"<`?+D$`#+`
M(```":S`Y?__^9S`,```"AW`(```"</`Y?__^9.R3P`0ZQ$`(``-LD\`$=4'
M\,@0**=T`#7C0/%```3KO_$H``0']+D$`#O`(```"?#`Y?__^*3L)@`:`'RG
M20`*P#````GN02#PM\#E___JM^PF_\\`?D$P\,'`(```"9[`Y?__^6"G]/_$
MN00`,L`@```)E,#E___Y5J?T_[K`Y?__Z!T'!P<'Z^_P<``DLD\`$./P_U#_
M<>L1`"``#;)/`!'$+0``-[_2!_"H$"CL*``8_WZR3P`0ZQ$`(``-LD\`$=4'
M\*@0*+D4`"*G=``KXT#Q(``$Z^_Q(``$!_1!,/"DP"````E:P.7___A(["@`
M%@!\XQ`@``"0[!@`$`!\P!<````PN0,`(>PB/[\!5<0O```WB*?T_\^G*```
MI_3_^<#E___GR^OO\'``)./P_V#_<<#E___GTL#E___G+^PH``T`?.,@(```
M!.-`\1``!.OO\1``!`?TIRD``*?T__<'!P<'!P?K;_`P`"2Y!`#OX_#_`/]Q
MI^O_^&"`X`"R3P`0ZQ$`(``-LD\`$=('\/`0*,`0```V^M(W\+@0`..@\+@`
M`J>$`#JY!`""0;#PP$%P\+3`T```",ZG]``1N00`.,#E___FNNPH`#T`?*>[
M``CCH+_X_P*GA``@N00`-[D$`"K`Y?__]\FY!`"2["@`!P!\E0`@`*=T_^.Y
M!``JN00`.*>[``C`Y?__^(OCH+_X_P*G=/_DLD\`$.L1`"``#;)/`!'5!_#P
M$"BG=`!!:(#P^.-`\7``!.MO\3``!`?TIP@``+D$`!BR7@`AIQ3__KD$`#FG
M&0``LEX`$Z<4__ZY"0`9N0D`*$$B$`*Y!`!HP.7__^?RXY#PJ``DX]#PH``D
ML\$`@L!0```(\J=)__^G.0`!P.7__^B`L\T`.+D$`"K`Y?__^#VG]/^2P.7_
M_^<$!P?K;_`P`"2Y!`#OX_#]Z/=QI^O_V&"`X`!@H.`(8,#@$&#@X!A@D.`@
MLD\`$.L1`"``#;)/`!'C,/'H"'%!</#$T@<P`!`HP!```#9ATA?PR!``P!``
M`#9GTB_P^!``P!```#9YTA?PX!``N00`DKD$`#?`(```"`C`Y?__]R3L*``)
M`'RY!`"RE0`@`*=T`CC`Y?___O"Y!`"R["@"/0!\N00`&Z<(``"G*0``LEX`
M(:<4__ZY"0`KZR(``0`-IRL``<#E___G;^,0L```D+D$`*(88>P8`!X`?+D$
M`(JY!``HN80`9L!0```(9*=)__^G.0`!0;"P`4&`@`+`Y?__Y_+C$+```)`8
M8>P6_^H`?.,@\/@``J>$`"M!L/$`I_0`":>[``CC(+_X_P*GA``@N00`-\#E
M___VQKD$`(+L*/_R`'R5`"``IX3_[<#E___YMNPH_^@`?KD$`"C`Y?__Y?*Y
M!`!B["8`)P!\IX@``+D4`!CK$0`#``WCL?#(``*GA`"ZE0"P`*>$`+:Y!``K
MIXH``<#E___YDNPH_^L`?KD$`"O`Y?__Y<[L*/_C`'RY!`!BIP@``+D$`!:G
MN0``LEX`L:<4__ZY!``JIQD``+)>`!*G%/_^N0D`&KD)`+8:L:>Z!`2Y%`"[
MN00`*\"````'5\#E___FUN.@\+``)..`\*``),`0```'W.,0\*@`)+/!`(*G
M.0`!P%````?-ITG__\#E___G7K/-`"BG.0'`P.7__^>'["8`"_]^P.7__^=!
M6!`@`.P6`^D1?L1H```U$>,@8```%L#E___H<[/-`#CL0@(``-FG*0`!P.7_
M_^AY&*+L*`!#`'ZSS0!HQ!@``#3PXU"0```$P$````>ZXR`0```$ISD``:>Y
M``#`Y?__Y["R3P`0XS#QZ`AQZQ$`(``-LD\`$;D$`"O5!S``$"BG=`/Q[8#Q
M\`AE[:#Q^`AE[<#R``AE[>#R"`AE[9#R$`AEXT#RB`@$ZV_R2`@$!_2G:0``
MI_3_7N,@8```%L#E___H'U@0(ABG*$``P!L``/``[!+_LV!VXR!@```6P.7_
M_^@/6-`B',#E___E>NS2_Z5@=N,@8```%L#E___H`5@0(ABG*`'`P!L```'_
M[!+_E6!VN00`*\#E___F(KD$`#>Y!`"RP"````<;P.7___6H["@!!`!\XW"0
M```$P.7__^3?N00`,KD$`"?`Y?__^E"Y!`!R["@`\@!\IP@``*<9``"Y!``G
MLEX`$J<4__ZY"0`7[!P`'P-^N10`(<`P```'2>,B?_S_<;)=`#*G%/_^IW0`
M$.P8`M`$?J<:__RY%``1XQ%___]QE2\0`*>$`L3`Y?___.WL)@`0`'ZY!``G
MISD``,#E___F.[D$`)(8<NPF`+D`?K/-`&C`,```!JC`(```!ES`D```!XK`
MY?__]AO`Y?__Y93`4```!QGC(/"H`"3C@/"@`"2Y!``KXY#PL``DITG__Z<Y
M``'`Y?__YC^G]``LP.7__^8J6!`@`*<>`!&G=``ML\T`:*>J``'`Y?__Y6VY
M%``:XR#PJ``DXY#PN``DN00`*^.`\*``),!0```&[.,0\+``)*=)__^G.0`!
MP.7__^83N00`*Z<Y`<#`Y?__YCSL*/_/_WZSS0`HP.7__^0DN00`.\`@```%
MT,#E___UP+D$`"O`Y?___-^G]/[7P.7___S:N00`*\#E___D';D$`+*G]/[+
MIZ@``+D4`!KK$0`#``WC(?#@``*GA``=N00`-^,A\.``!*>J``'`Y?__],/L
M*/_L`'R5`"``IX3_Y\#E___C^>PH_^(`?+D$`+*G]/VAIRD`#<"P```&(*=H
M`%/`Y?__Y1BY!`"BI_3]L.-PD```!*?T_PZG20`"ISG_[L#E___DR$$0\>BY
M!``IL\$`P;D$`#&G20`&P.7__^.+E0#QZ*=T``:50_'IIX0"2[D4`!>Y!``I
ML\$`D:=)``"G.0``06#Q**?8`$"SP0"KP.7__^2@P!%G12,!XQ#Q*``DP!_O
MS:N)XQ#Q,``DP!^8NMS^XQ#Q.``DP!$0,E1VXQ#Q0``DP!_#TN'PY4CQ4```
MXQ#Q2``DY4CQ6```01#Q8.5,\:```+/!`.&SS0`\L\T`*:5/@`#`Y?__XSRY
M!`"2&'+L+`")`'ZY%``IXS#Q4``$ZQ(``P`-XT#Q6``$N0@`$\`:`````.PQ
M``7`9:=+``'C$/%0`"3K(@`=``RYZ$`2XQ#Q6``DXQ#QH``2IX0!8[/-`"ZY
M^1!]L\T`/!F7N?+`>;D8`"&Y%`"GN00`2L#E___C3Q@76A#QH%`0\:#L%O^U
M0'ZSS0`<N00`)KGY<'E!JA``P.7__^A(['P`(#]^[!?_P`#8Z[$`!@#>[)LF
MOP!5IYL``=(_\6"@`+D$`"9!H*!`P.7__^@PIY?_]J=Z_\#K&P`&`-\;<;/-
M`"ZY%`!'N00`.J=9`$C`Y?__Y%&SS0`\L\T`*5!P\:"E3X``P.7__^*VN00`
MDAAR["+_?0!^L\T`*;/-`+K`Y?__YAGCH/%0``3CD/%8``3L*CJ_/56Y%``2
M01'Q8)*`$`"G*@`!["(!%#A^L\T`'J<X`#BY&``2N?D@(^PH`!H`?J<J___K
M,@`(`-[L.``-`'[C(!0``#;7_Q``$`!!$!$`IS;_^+D6`"+&(````6E"D/&;
M0J#QG^L9`!@`#$(0\9CK&0`0``Q"$/&9ZSH`&``,0C#QG.L:`!``#$(0\9VY
M!``FZYD`"``,0I#QFNNJ``@`#$*@\9Y!D/&_07#QK*>I`!3`Y?__YZ+C$/$H
M``1"$/&NZR$`$``,0B#QK.LA``@`#$(@\:WK80`8``SC$/$P``1"$/&RZR$`
M&``,0B#QK^LA`!``#$(@\;#K$0`(``Q"$/&QXQ#Q.``$0A#QMNLA`!@`#$(@
M\;/K(0`0``Q"(/&TZQ$`"``,0A#QM>,0\4``!$(0\;KK(0`8``Q"(/&WZR$`
M$``,ZQ$`"``,0B#QN$(0\;GC$/%(``3K(0`8``Q"$/&^0B#QNT)@\:OK(0`0
M``SK$0`(``Q"(/&\0A#QO;D$`"FYA`!FIYL``L!0```$4*=)__^G.0`!P.7_
M_^/BIZ<`)K/-`&A!$/&_N00`*Y(`\>?C$/"H`"3`$```!0+C@/"@`"3`4```
M!(SC$/"P`"2G2?__ISD``<#E___CPJ?T_;FSS0"LI_3^PD-@<`"G>P`!I_3_
MQN,0D`@``J>$_3NG"```IRD``+D$`#&R7@`CIQ3__KD)`"'L+/TM`WWC,A_\
M_W'`(```!%FR70`CIQ3__KGB@'&G]/T>L\T`/J<8`$"Y&``RN?D@(>PH`!P`
M?J<J__^Y!``3ZS(`"`#>[#@`#0!^XR`4```VU_\0`!``01`1`*<V__BY%@`B
MQB````!9N00`)L#E___FM]<W\6#Q8*?T_N6SS0!HN10`$>-0D```!.,0\*``
M),08```Q&<!````#R.,@$```!*<Y``&GN0``P.7__^/<I_3\+)5!\>JG=/VU
ME4/QZZ=T_;&52/'LIW3]K95%\>VG=/VIITD``J<Y_\:Y!``IL\T`:,#E___B
M3[/-`#RY!``IITD`*<#E___A%KD$`"M@P/"HI_3_3<#E___AK=<`$``0`-<`
M$``0`.MO\#``)+)/`!#K$0`@``VR3P`1X_#_4/]QQ+@``##/T@?PJ!`HXR"P
M```60=#PI,#E___D++D$`*+C(+```!;`Y?__Y"32`""YH+BY!``]P"````+=
MP.7___'9["@`!P!\E3$@`*>$`8+`Y?__^&OC(+```!;`Y?__Y`FG60`+ITD`
M`<`P```#N\#E___B/^PH`6D`?.,@(!``!%@0L`#C8"`H``3`(```.1GE7"``
M``&GQ`!LIX@``*>H``&G]``7XR`@$``$IP@``,0]```Y!K)=`">G%/_^IW0`
M4J>*``&GJ@`![#H`3,!VN18`(<#E___CS+D$`#:G60``N10`2,#E___C8[D$
M`)+L*`$U`'S$.```.-^Y%``:ZQ$``P`-XR`@```$XW$P```$IT@$`%@P(`Q8
M$+``P#L`(`0`[#3_P8!VN18`(<#E___CG^,PD```!*=9``*G20``P.7__^%%
MIP@``%@0L`#$/0``.+:R70`GIQ3__J>$_[+L(___`-CL*`#!@':Y%@`AP.7_
M_^-]IUD``Z=)``'`,````S+`Y?__X;.Y!`"B["@`'P!\XR"P```6P.7__^-H
MXQ"@$``$P$````,?XS`0```$P.7__^#\XQ"@$``$XQ`0```$D4`0#:=T`.GC
M(+```!;`Y?__XTRG60`#ITD``<`P```#!<#E___A@KD$`*+L*``A`'RY!``]
MP"````'>P.7___#UN00`DN,@L```%NR8`+$`?,#E___C*N,0H!``!+D$`$GC
M,!````3`Y?__X+_C(+```!;`Y?__XQFY!`"BXR"P```6P.7__^,1ITD``<`P
M```"S<#E___AN<!````"TKD$`#*Y!``JP.7__^"?XR"P```6P.7__^+YD@`@
MN;D$`#W`(````9/`Y?__\*_$*P``.!BY!`"R["@`0`!\N00`*Z<Y`<#`Y?__
MX>#L*``)$7[L$@`!`-CL$@"#`7^R3P`0ZQ$`(``-LD\`$=4'\*@0**=T`'/C
M0/$@``3K;_#@``0'].P\_T(!?J>H``&Y%@`AIZH``<#E___BN+D$`#;`Y?__
MW]-8$+``QJT``#?6IT3_[Z?T_RK$*```-\O`Y?__^03$*P``-\VY!`"R[";_
MN`!\P"````)HP.7__^%V6!"P`*?T_Q*5`"`!IX3^@:?T_GS$/0``-[%8$+``
M["/__P#8["C_`F!VI_3_O<#E___B?,08```WG>,@H!``!.,P$```!.,@(```
M!,#E___SB:?T_T[C(+```!;`Y?__XF7C$*`0``3C,!````3`Y?__X8RG]/\*
MP.7__]^WQ!@``#=XN00`4KD$`$O`(````BWC,!````3`Y?__X2?KK_!0`"3C
M\/]8_W&Y!`"BP.7___8`XQ`@``"0[!@`-@!\&#&Y!`"R0C#PIY4O\*=!("`!
MXQ`@``"0N>*`LA@Q[!;_]`!\P.7___=I["@`%P!^[*@`%`!\E0"@`*>$``^Y
M!``KITD`!,`P```!3\#E___A[>PH``X`?N-`\1@`!.NO\/@`!`?TN00`LJ?T
M_]VY!``JZZ_P^``$P/3___'SP!```"Z8XQ`0```"IX0`".-0$```!,#T___?
MR<!0```NJL#T___?P^M_\#@`)./P_V#_<;D$`)*Y!`"#N00`=,"P```L4,#E
M___>0<`0```L1KD)`+'KNP`#``KLN``3`'RY!`"AXQ"@```$N00`1[D$`#BY
M!``IIZL`"`WAI[?_].-`\1``!.M_\-@`!`?T!_X'!P<'!P?K;_`P`"2Y!``?
MI_O_8.,0\```),#````M+@<'XT#Q$``$ZV_PT``$!_0'!P```````@`!+@`N
M+@``)7,O)7,`+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```+W!R;V,O)6DO)7,`97AE
M`%!!4E]414U0``!005)?4%)/1TY!344``#H`+P!015),-4Q)0@``4$523$Q)
M0@!015),-4]05```4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,``%!!
M4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?5$U01$E2
M`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.
M``!005)?0TQ%04X]```Q`$Q)0E!!5$@`3$E"4D%265]0051(``!$64Q$7TQ)
M0E)!4EE?4$%42`!32$Q)0E]0051(``!365-414T``"4P,G@``"5S)7,E<R5S
M``!P87(M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*``!P87)L```N<&%R```E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S```O=&UP``!414U01$E2
M`%1-4`!54T52``!54T523D%-10``05)'5@``&`!P97)L```P`%!!4CHZ4&%C
M:V5R.CI615)324].```Q+C`S-@!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``+64``"TM``!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L
M;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF
M:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P
M87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N
M9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?
M05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%
M3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E
M;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@
M("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@
M/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T
M96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("13
M24=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA
M;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]
M("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ
M.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S
M:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I
M;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(
M+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G
M;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R
M:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@
M?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*
M)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E
M="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&
M2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@
M)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK
M97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%
M)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[
M4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D
M92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L
M(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB
M=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N
M)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@
M)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD
M("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"([
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%
M3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@
M)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D[
M"F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G
M)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E
M;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD
M;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN
M;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S
M<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@
M*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D
M96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]
M?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y
M*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A
M;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N
M("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD
M9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@
M>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I
M;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S
M:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H
M("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H
M+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I
M(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO
M*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE
M*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T
M(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\
M1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F
M:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*
M*2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*
M)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA
M;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H
M95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI6
M15)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L
M(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@
M)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<
M,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N
M/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F
M:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U
M-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@
M96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D
M97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]
M($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D
M<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE
M+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L
M:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U
M:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR
M97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R
M;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<[
M"G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V
M86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE
M=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@
M07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ
M2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@
M<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X
M('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?
M=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@
M)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@
M5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S
M(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@
M)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U
M:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ
M3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I
M9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<[
M"FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII
M9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R
M;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D[
M"G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII
M9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES
M<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*
M?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M
M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC
M;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0[
M"GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N
M86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B
M)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@
M)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L
M("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B
M.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F
M:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G
M;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY
M("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@
M7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN
M,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE
M(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF
M:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*
M?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE4
M24%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$
M14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@```%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@```````````?_________W!E<FQX
M<VDN8P`````````!&P,[````U````!G__X-8```%5/__AO````#P__^>.```
M`3#__Y\@```!@/__G^````&P__^BL````?#__Z0P```"+/__I/````)H__^F
M$````J3__Z90```"Q/__IK````,`__^GH````SS__Z>H```#4/__J?````.,
M__^J0````ZS__ZMP```#T/__K4@```0`__^MZ```!"3__ZXH```$2/__KW@`
M``2(__^Z,```!-C__[XP```%&/__OM````68__^^^```!;#__[]@```%Z```
M```````4``````%Z4@`!>`X!&PP/H`$````````\````'/__A?@``!=$`%B&
M#H<-B`R)"XH*BPF,"(T'C@:/!48.R`<#%QX*S\[-S,O*R<C'Q@Z@`4(+````
M````3````%S__YT`````X@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L`"`H@*
MS\[-S,O*R<C'Q@Z@`4(+`D(*S\[-S,O*R<C'Q@Z@`4(+```````L````K/__
MG9@```"\`$J*"HL)C`B-!XX&CP5&#M`"`J0*S\[-S,O*#J`!0@L````\````
MW/__GB@```+*`$J&#H<-B`R)"XH*BPF,"(T'C@:/!48.V`(#`78*S\[-S,O*
MR<C'Q@Z@`4(+````````.````1S__Z"X```!>@!*A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5&#N`#`D8*S\[-S,O*R<C'Q@Z@`4(+````.````5C__Z'\````O`!&
MB@J+"8P(C0>.!H\%1@[``@)$"L_.S<S+R@Z@`4(+`F#/SLW,R\H.H`$`````
M.````93__Z*````!'@!*APV(#(D+B@J+"8P(C0>.!H\%1@[((@*^"L_.S<S+
MRLG(QPZ@`4(+````````'````=#__Z-D````/`!,C@:/!48.P`)DS\X.H`$`
M```X```!\/__HX0```!@`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.R`("4L_.
MS<S+RLG(Q\8.H`$````````X```"+/__HZ@```#J`$J&#H<-B`R)"XH*BPF,
M"(T'C@:/!48.V$("R@K/SLW,R\K)R,?&#J`!0@L````0```":/__I%P````&
M`````````#@```)\__^D4````D@`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@
M(@*$"L_.S<S+RLG(Q\8.H`%""P```!P```*X__^F7````$H`5`D/$$@.R`)F
MSPZ@`0``````(````MC__Z:,```!+@`"THX&CP5&#L`"9L_.#J`!````````
M+````OS__Z>8```!U`!4BPF,"(T'C@:/!48.\`(#`5H*S\[-S,L.H`%""P``
M````(````RS__ZE`````H`!*C@:/!48.T`("1`K/S@Z@`4(+````(````U#_
M_ZF\````.@!&C@:/!48.P`)D"L_.#J`!0@L`````/````W3__ZG8```!3@!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5*#J`#2)@5`L(*S\[-S,O*R<C'QM@.H`%"
M"P```$P```.T__^JZ```"K@`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@ZXA0)8
MF!F9&)H7FQ:<%0,"R@K/SLW,R\K)R,?&W-O:V=@.H`%""P``````/```!`3_
M_[50```$``!4A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`"`P+J"L_.S<S+RLG(
MQ\8.H`%""P```````#@```1$__^Y$````*``1HH*BPF,"(T'C@:/!48.R`("
M>@K/SLW,R\H.H`%""U+/SLW,R\H.H`$``````$````2`__]]_````HX`1H8.
MAPV(#(D+B@J+"8P(C0>.!H\%3`[H`@,!V@K/SLW,R\K)R,?&#J`!0@L`````
M````````%```!,3__[DP````*```````````````-```!-S__[E`````:`!&
MAPV(#(D+B@J+"8P(C0>.!H\%1@[``@):S\[-S,O*R<C'#J`!```````0```%
M%/__N7`````"````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+1``
M```````LP``````````!``````````$``````````0````````'&````````
M``$````````"%0`````````=````````!*D`````````#````````"'`````
M``````T```````!ED``````````9````````O=``````````&P`````````(
M`````````!H```````"]V``````````<``````````@`````````!```````
M``*0`````&___O4````````(R``````````%````````$P@`````````!@``
M``````FH``````````H````````$W0`````````+`````````!@`````````
M%0````````````````````,```````#````````````"````````!8@`````
M````%``````````'`````````!<````````<.``````````'````````&2``
M````````"`````````,8``````````D`````````&`````!O___[``````@`
M````````;____@```````!BP`````&____\``````````@````!O___P````
M````%^8`````;___^0`````````5````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"]X``````````````````````````````B+@``
M`````").````````(FX````````BC@```````"*N````````(LX````````B
M[@```````",.````````(RX````````C3@```````"-N````````(XX`````
M```CK@```````"/.````````(^X````````D#@```````"0N````````)$X`
M```````D;@```````"2.````````)*X````````DS@```````"3N````````
M)0X````````E+@```````"5.````````)6X````````EC@```````"6N````
M````)<X````````E[@```````"8.````````)BX````````F3@```````"9N
M````````)HX````````FK@```````";.````````)NX````````G#@``````
M`"<N````````)TX````````G;@```````">.````````)ZX````````GS@``
M`````"?N````````*`X````````H+@```````"A.````````*&X````````H
MC@```````"BN````````*,X````````H[@```````"D.````````*2X`````
M```I3@```````"EN````````````````````````````````````````````
M``````````````````````````````````````#":```````````````````
M```````````I@```````````````````````````````````````````````
M````PF@```````!G*@```````&<2````````9QH```````!G0````````&<H
M````````9SH``````````````````&@P````````9<0`````````````````
M`&;6````````9MH```````!H-@```````&8F````````:#X`````````````
M`````&A"````````:$@``````````/____\`````````````:.I'0T,Z("A3
M55-%($QI;G5X*2`W+C,N,2`R,#$X,#,R,R!;9V-C+3<M8G)A;F-H(')E=FES
M:6]N(#(U.#@Q,ET``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`
M+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP
M;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE
M:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T
M`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````
M````````````````````````````````````````````````````````````
M``````L````!``````````(````````".`````````(X``````````\`````
M```````````````!```````````````3````!P`````````"`````````D@`
M```````"2``````````@````````````````````!```````````````(0``
M``<``````````@````````)H`````````F@`````````)```````````````
M``````0``````````````#@````%``````````(````````"D`````````*0
M````````!C@````&```````````````(``````````@````T;___]@``````
M```"````````",@````````(R`````````#<````!@``````````````"```
M````````````/@````L``````````@````````FH````````":@````````)
M8`````<````"``````````@`````````&````$8````#``````````(`````
M```3"````````!,(````````!-T````````````````````!````````````
M``!.;____P`````````"````````%^8````````7Y@````````#(````!@``
M`````````````@`````````"````6V____X``````````@```````!BP````
M````&+``````````<`````<````"``````````@``````````````&H````$
M``````````(````````9(````````!D@`````````Q@````&````````````
M```(`````````!@```!T````!`````````!"````````'#@````````<.```
M``````6(````!@```!8`````````"``````````8````?@````$`````````
M!@```````"'`````````(<``````````0`````````````````````0`````
M`````````'D````!``````````8````````B`````````"(`````````!X``
M```````````````````$`````````"````"$`````0`````````&````````
M*8`````````I@````````#P0````````````````````"```````````````
MB@````$`````````!@```````&60````````99``````````+```````````
M``````````0``````````````)`````!``````````(```````!EP```````
M`&7`````````0&@````````````````````(``````````````"8`````0``
M```````"````````IB@```````"F*`````````#4````````````````````
M!```````````````I@````$``````````@```````*<`````````IP``````
M```%*`````````````````````@``````````````+`````.``````````,`
M``````"]T````````*W0``````````@````````````````````(````````
M``@```"\````#P`````````#````````O=@```````"MV``````````(````
M````````````````"``````````(````R`````8``````````P```````+W@
M````````K>`````````"(`````<```````````````@`````````$````-$`
M```!``````````,```````#``````````+```````````F``````````````
M```````(``````````@```#6`````0`````````#````````PF````````"R
M8`````````"X````````````````````"```````````````W`````@`````
M`````P```````,,8````````LQ@````````0,`````````````````````@`
M`````````````.$````!`````````#```````````````````+,8````````
M`$`````````````````````!``````````$````!`````P``````````````
M``````````````"S6`````````#J`````````````````````0``````````
